==> mahara_1.2.4.orig.tar.gz: mahara-1.2.4/htdocs/export/leap/lang/en.utf8/export.leap.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage export.leap
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'LEAP2A';
// TODO: link LEAP2A standard format to a primer document on our wiki about LEAP2A
$string['description'] = 'Gives you an export in the <a href="">LEAP2A standard format</a>. You can later use this to import your data into <a href="http://wiki.mahara.org/Developer_Area/Import%%2f%%2fExport/Interoperability">other LEAP2A compliant systems</a>, although the export is hard for humans to read.';

?>

==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/export/leap/lang/en.utf8/export.leap.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage export.leap
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Leap2A';
// TODO: link Leap2A standard format to a primer document on our wiki about Leap2A
$string['description'] = 'Gives you an export in the <a href="http://wiki.leapspecs.org/2A/specification">Leap2A standard format</a>. You can later use this to import your data into <a href="https://wiki.mahara.org/index.php/Developer_Area/Import//Export/Interoperability">other Leap2A compliant systems</a>, although the export is hard for humans to read.';
